@@ -2,7 +2,7 @@ use warnings;
 use strict;
 package Mojolicious::Plugin::Mongodb;
 {
-  $Mojolicious::Plugin::Mongodb::VERSION = '1.10';
+  $Mojolicious::Plugin::Mongodb::VERSION = '1.11';
 }
 use Mojo::Base 'Mojolicious::Plugin';
 use MongoDB;
@@ -43,10 +43,7 @@ sub register {
                 $opts->{'$keyf'} = delete($opts->{'keyf'}) if($opts->{'keyf'});
                 $opts->{'$finalize'} = delete($opts->{'finalize'}) if($opts->{'finalize'});
 
-                my $cmd = Tie::IxHash->new(
-                    "group" => $opts
-                );
-                return $self->_database->run_command($cmd);
+                return $self->find_one({ group => $opts });
             }, name => 'group', package_name => 'MongoDB::Collection'));
 
             $meta->add_method('find_and_modify' => Moose::Meta::Method->wrap(sub {
@@ -82,7 +79,7 @@ sub register {
 
 package Mojolicious::Plugin::Mongodb::Connection;
 {
-  $Mojolicious::Plugin::Mongodb::Connection::VERSION = '1.10';
+  $Mojolicious::Plugin::Mongodb::Connection::VERSION = '1.11';
 }
 use Mojo::Base -base;
 use Tie::IxHash;
@@ -151,13 +148,13 @@ sub group {
     my $collection = shift;
     my $opts = shift;
 
-    $opts->{ns} = $collection;
+    # fix the shit up
+    $opts->{'ns'} = $self->name,
+    $opts->{'$reduce'} = delete($opts->{'reduce'}) if($opts->{'reduce'});
+    $opts->{'$keyf'} = delete($opts->{'keyf'}) if($opts->{'keyf'});
+    $opts->{'$finalize'} = delete($opts->{'finalize'}) if($opts->{'finalize'});
 
-    my $cmd = Tie::IxHash->new( 
-        "group" => $opts
-    );
-
-    return $self->db->run_command($cmd);
+    return $self->find_one({ group => $opts });
 }
 
 1; 
@@ -168,7 +165,7 @@ Mojolicious::Plugin::Mongodb - Use MongoDB in Mojolicious
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
